@@ -6,10 +6,14 @@ def assert_equals_with_unidiff(expected, actual):
         expected=expected.splitlines(1)
         actual=actual.splitlines(1)
 
-        diff=difflib.unified_diff(expected, actual, 
-                                 fromfile='Expected', tofile='Actual', 
+        diff=difflib.unified_diff(expected, actual,
+                                 fromfile='Expected', tofile='Actual',
                                  lineterm='\n', n=10)
 
         return ''.join(diff)
     from nose.tools import assert_equals
-    assert_equals(expected, actual, "\n" + unidiff(expected, actual))
+    assert_equals(expected, actual,
+                  "\n"
+                  "Expected:%s\n" % repr(expected) +
+                  "  Actual:%s\n" % repr(actual) +
+                  unidiff(expected, actual))
