@@ -1,19 +1,20 @@
 # Copyright (C) 2011 Andrea Francia Trivolzio(PV) Italy
 
 import os
-from trashcli.trash import ListCmd
-from files import (write_file, require_empty_dir, make_sticky_dir,
+from trashcli.list import ListCmd
+from .files import (write_file, require_empty_dir, make_sticky_dir,
                    make_unsticky_dir, make_unreadable_file, make_empty_file,
                    make_parent_for)
 from nose.tools import istest
 from .output_collector import OutputCollector
-from trashinfo import (
+from .trashinfo import (
         a_trashinfo,
         a_trashinfo_without_date,
         a_trashinfo_without_path,
         a_trashinfo_with_invalid_date)
 from textwrap import dedent
 
+from .assert_equals_with_unidiff import assert_equals_with_unidiff
 class Setup(object):
     def setUp(self):
         require_empty_dir('XDG_DATA_HOME')
@@ -28,7 +29,17 @@ class Setup(object):
         make_sticky_dir(path)
     def when_dir_exists_unsticky(self, path):
         make_unsticky_dir(path)
-
+    def user_run_trash_list(self, *args):
+        self.user.run_trash_list(*args)
+    def user_should_read_output_any_order(self, expected_output):
+        actual_output = self.user.actual_output()
+        assert_equals_with_unidiff(sort_lines(expected_output),
+                                   sort_lines(actual_output))
+    def user_should_read_output(self, expected_output):
+        assert_equals_with_unidiff(expected_output,
+                                   self.user.actual_output())
+def sort_lines(lines):
+    return "".join(sorted(lines.splitlines(True)))
 
 @istest
 class describe_trash_list(Setup):
@@ -36,9 +47,9 @@ class describe_trash_list(Setup):
     @istest
     def should_output_the_help_message(self):
 
-        self.user.run('trash-list', '--help')
+        self.user_run_trash_list('--help')
 
-        self.user.should_read_output(dedent("""\
+        self.user_should_read_output(dedent("""\
             Usage: trash-list [OPTIONS...]
 
             List trashed files
@@ -47,23 +58,23 @@ class describe_trash_list(Setup):
               --version   show program's version number and exit
               -h, --help  show this help message and exit
 
-            Report bugs to http://code.google.com/p/trash-cli/issues
+            Report bugs to https://github.com/andreafrancia/trash-cli/issues
         """))
 
     @istest
     def should_output_nothing_when_trashcan_is_empty(self):
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output('')
+        self.user_should_read_output('')
 
     @istest
     def should_output_deletion_date_and_path(self):
         self.add_trashinfo('/aboslute/path', '2001-02-03T23:55:59')
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output( "2001-02-03 23:55:59 /aboslute/path\n")
+        self.user_should_read_output( "2001-02-03 23:55:59 /aboslute/path\n")
 
     @istest
     def should_output_info_for_multiple_files(self):
@@ -71,9 +82,10 @@ class describe_trash_list(Setup):
         self.add_trashinfo("/file2", "2000-01-01T00:00:02")
         self.add_trashinfo("/file3", "2000-01-01T00:00:03")
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output( "2000-01-01 00:00:01 /file1\n"
+        self.user_should_read_output_any_order(
+                                      "2000-01-01 00:00:01 /file1\n"
                                       "2000-01-01 00:00:02 /file2\n"
                                       "2000-01-01 00:00:03 /file3\n")
 
@@ -82,23 +94,23 @@ class describe_trash_list(Setup):
 
         self.home_trashcan.having_file(a_trashinfo_without_date())
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output("????-??-?? ??:??:?? /path\n")
+        self.user_should_read_output("????-??-?? ??:??:?? /path\n")
 
     @istest
     def should_output_invalid_dates_using_question_marks(self):
         self.home_trashcan.having_file(a_trashinfo_with_invalid_date())
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output("????-??-?? ??:??:?? /path\n")
+        self.user_should_read_output("????-??-?? ??:??:?? /path\n")
 
     @istest
     def should_warn_about_empty_trashinfos(self):
         self.home_trashcan.touch('empty.trashinfo')
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error(
                 "Parse Error: XDG_DATA_HOME/Trash/info/empty.trashinfo: "
@@ -108,7 +120,7 @@ class describe_trash_list(Setup):
     def should_warn_about_unreadable_trashinfo(self):
         self.home_trashcan.having_unreadable('unreadable.trashinfo')
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error(
                 "[Errno 13] Permission denied: "
@@ -117,12 +129,12 @@ class describe_trash_list(Setup):
     def should_warn_about_unexistent_path_entry(self):
         self.home_trashcan.having_file(a_trashinfo_without_path())
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error(
                 "Parse Error: XDG_DATA_HOME/Trash/info/1.trashinfo: "
                 "Unable to parse Path.\n")
-        self.user.should_read_output('')
+        self.user_should_read_output('')
 
 @istest
 class with_a_top_trash_dir(Setup):
@@ -137,16 +149,16 @@ class with_a_top_trash_dir(Setup):
         self.when_dir_is_sticky('topdir/.Trash')
         self.and_contains_a_valid_trashinfo()
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output("2000-01-01 00:00:00 topdir/file1\n")
+        self.user_should_read_output("2000-01-01 00:00:00 topdir/file1\n")
 
     @istest
     def and_should_warn_if_parent_is_not_sticky(self):
         self.when_dir_exists_unsticky('topdir/.Trash')
         self.and_dir_exists('topdir/.Trash/123')
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error("TrashDir skipped because parent not sticky: topdir/.Trash/123\n")
 
@@ -155,7 +167,7 @@ class with_a_top_trash_dir(Setup):
         self.when_dir_exists_unsticky('topdir/.Trash')
         self.but_does_not_exists_any('topdir/.Trash/123')
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error("")
 
@@ -164,25 +176,25 @@ class with_a_top_trash_dir(Setup):
         self.when_dir_exists_unsticky('topdir/.Trash')
         self.and_contains_a_valid_trashinfo()
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output("")
+        self.user_should_read_output("")
 
     @istest
     def it_should_ignore_Trash_is_a_symlink(self):
         self.when_is_a_symlink_to_a_dir('topdir/.Trash')
         self.and_contains_a_valid_trashinfo()
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
-        self.user.should_read_output('')
+        self.user_should_read_output('')
 
     @istest
     def and_should_warn_about_it(self):
         self.when_is_a_symlink_to_a_dir('topdir/.Trash')
         self.and_contains_a_valid_trashinfo()
 
-        self.user.run_trash_list()
+        self.user_run_trash_list()
 
         self.user.should_read_error('TrashDir skipped because parent not sticky: topdir/.Trash/123\n')
     def but_does_not_exists_any(self, path):
@@ -207,39 +219,9 @@ class describe_when_a_file_is_in_alternate_top_trashdir(Setup):
         self.top_trashdir2 = FakeTrashDir('topdir/.Trash-123')
         self.top_trashdir2.add_trashinfo('file', '2000-01-01T00:00:00')
 
-        self.user.run_trash_list()
-
-        self.user.should_read_output("2000-01-01 00:00:00 topdir/file\n")
-
-@istest
-class describe_trash_list_with_raw_option:
-    def setup(self):
-        self.having_XDG_DATA_HOME('XDG_DATA_HOME')
-        self.running('trash-list', '--raw')
-    @istest
-    def output_should_contains_trashinfo_paths(self):
-        from nose import SkipTest; raise SkipTest()
-        self.having_trashinfo('foo.trashinfo')
-        self.output_should_contain_line(
-            'XDG_DATA_HOME/Trash/info/foo.trashinfo')
-    @istest
-    def output_should_contains_backup_copy_paths(self):
-        from nose import SkipTest; raise SkipTest()
-        self.having_trashinfo('foo.trashinfo')
-        self.output_should_contain_line(
-            'XDG_DATA_HOME/Trash/files/foo')
-
-    def having_XDG_DATA_HOME(self, value):
-        self.XDG_DATA_HOME = value
-    def running(self, *argv):
-        user = TrashListUser( environ = {'XDG_DATA_HOME': self.XDG_DATA_HOME})
-        user.run(argv)
-        self.output = user.output()
-    def output_should_contain_line(self, line):
-        assert line in self.output_lines()
-    def output_lines(self):
-        return [line.rstrip('\n') for line in self.output.splitlines()]
+        self.user_run_trash_list()
 
+        self.user_should_read_output("2000-01-01 00:00:00 topdir/file\n")
 
 class FakeTrashDir:
     def __init__(self, path):
@@ -272,8 +254,8 @@ class TrashListUser:
         self.environ     = environ
         self.fake_getuid = self.error
         self.volumes     = []
-    def run_trash_list(self):
-        self.run('trash-list')
+    def run_trash_list(self, *args):
+        self.run('trash-list', *args)
     def run(self,*argv):
         from trashcli.trash import FileSystemReader
         file_reader = FileSystemReader()
@@ -292,10 +274,10 @@ class TrashListUser:
         self.volumes.append(mount_point)
     def error(self):
         raise ValueError()
-    def should_read_output(self, expected_value):
-        self.stdout.assert_equal_to(expected_value)
     def should_read_error(self, expected_value):
         self.stderr.assert_equal_to(expected_value)
     def output(self):
         return self.stdout.getvalue()
+    def actual_output(self):
+        return self.stdout.getvalue()
 
