@@ -1,7 +1,7 @@
 # Copyright (C) 2011 Andrea Francia Trivolzio(PV) Italy
 
 from nose.tools import assert_equals
-from trashcli.trash  import has_sticky_bit
+from trashcli.fs  import has_sticky_bit
 import os, shutil
 
 def having_file(path):
@@ -14,8 +14,8 @@ make_empty_file = having_file
 def write_file(filename, contents=''):
     parent = os.path.dirname(filename)
     if not os.path.isdir(parent): os.makedirs(parent)
-    file(filename, 'w').write(contents)
-    assert_equals(file(filename).read(), contents)
+    open(filename, 'w').write(contents)
+    assert_equals(open(filename).read(), contents)
 
 def require_empty_dir(path):
     if os.path.exists(path): shutil.rmtree(path)
@@ -73,5 +73,5 @@ def make_unreadable_file(path):
     os.chmod(path, 0)
     from nose.tools import assert_raises
     with assert_raises(IOError):
-        file(path).read()
+        open(path).read()
 
