@@ -1,8 +1,8 @@
-from assert_equals_with_unidiff import assert_equals_with_unidiff
+from .assert_equals_with_unidiff import assert_equals_with_unidiff
 
 class OutputCollector:
     def __init__(self):
-        from StringIO import StringIO
+        from unit_tests.myStringIO import StringIO
         self.stream = StringIO()
         self.getvalue = self.stream.getvalue
     def write(self,data):
@@ -10,9 +10,11 @@ class OutputCollector:
     def assert_equal_to(self, expected):
         return self.should_be(expected)
     def should_be(self, expected):
-        assert_equals_with_unidiff(expected, self.stream.getvalue())
+        assert_equals_with_unidiff(expected, self.output())
     def should_match(self, regex):
-        text = self.stream.getvalue()
+        text = self.output()
         from nose.tools import assert_regexp_matches
         assert_regexp_matches(text, regex)
+    def output(self):
+        return self.stream.getvalue()
 
